<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Flask-WebpackExt Example</title>
    {{ webpack['styles.css'] }}
  </head>
  <body>
    <div align="center">
      <h1>Hello, webpack!</h1>
      <button type="button" class="btn btn-primary btn-lg" data-toggle="modal" data-target="#myModal">
        Press me
      </button>
      <div class="modal fade" id="myModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
        <div class="modal-dialog" role="document">
          <div class="modal-content">
            <div class="modal-header">
              <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              <h4 class="modal-title" id="myModalLabel">Greetings from Flask-WebpackExt</h4>
            </div>
            <div class="modal-body">
              Just checking if bootstrap.js has been loaded.
            </div>
            <div class="modal-footer">
              <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
            </div>
          </div>
        </div>
      </div>
    </div>
    {{ webpack['manifest.js'] }}
    {{ webpack['vendor.js'] }}
    {{ webpack['app.js'] }}
  </body>
</html>
